#
# spec file for package python-adal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-adal
Version:        1.2.7
Release:        4.2
Summary:        Azure Active Directory library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/AzureAD/azure-activedirectory-library-for-python
Source:         https://files.pythonhosted.org/packages/source/a/adal/adal-%{version}.tar.gz
Source1:        HISTORY.txt
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyJWT >= 1.0.0
Requires:       python-cryptography >= 1.1.0
Requires:       python-python-dateutil >= 2.1.0
Requires:       python-requests >= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-adal <= 1.2.7
%endif
BuildArch:      noarch

%python_subpackages

%description
The ADAL for Python library makes it easy for python application to authenticate to
Azure Active Directory (AAD) in order to access AAD protected web resources.

%prep
%setup -q -n adal-%{version}
cp %{SOURCE1} HISTORY.txt

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc HISTORY.txt README.md
%{python_sitelib}/adal
%{python_sitelib}/adal-*.dist-info

%changelog
* Fri May  3 2024 Robert Schweikert <rjschwei@suse.com>
- Change version setting of Obsoletes to <= to trigger python3
  binary removal since there was no source version bump
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
* Thu Mar 21 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Drop definition of BuildRoot
- Limit Python files matched in %%files section
* Mon May 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.7
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Thu Mar 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.6
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Nov 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.5
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update HISTORY.txt from github releases page
* Tue Jun 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.4
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update HISTORY.txt from github releases page
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.2
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update HISTORY.txt from github releases page
* Mon Mar  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.2.1
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Run %%fdupes with %%python_expand
- Update Url field to point to actual project homepage
* Mon Sep  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.2
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Update Requires from setup.py
* Wed Jan 31 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.5.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Install HISTORY.txt into doc directory
- Install README.md into doc directory
- Remove patches merged upstream
  + 0001-Forcing-utf8-decoding.patch
* Tue Jul 11 2017 adrian.glaubitz@suse.com
- Update package names in Requires
  + Rename python-dateutil to python-python-dateutil
* Mon Jul 10 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.4.5
- Provide full source URL in Source field
- Convert package to single spec
- Add patch from upstream to enforce UTF-8 decoding
  + 0001-Forcing-utf8-decoding.patch
* Mon Dec 12 2016 ms@suse.com
- Include in SLE 12 (fate#322171, bsc#1014478)
* Mon Dec 12 2016 ms@suse.com
- Initial build
  + Version 0.4.3
